<?PHP /* This is the global configuration file; common code and default parameters go here */

$DEFAULT_IDM='en'; /* Default language to start with, and if for any reason we don't get the correct parameter */
$ALBPREFIX='mpa_'; /* Prefix with which all album directories will start; if it is a directory, it MUST end with a slash */
$PICPREFIX='pictures/'; /* The prefix to identify the pictures; if it is a directory, it MUST end with a slash */
$THUMBPREFIX='thumbs/'; /* The prefix to identify the thumbnails; if it is a directory, it MUST end with a slash */
$THUMBWIDTH=80; /* The width for the newly created thumbs (or height, if the image is in portrait format) */
$THUMBHEIGHT=55; /* The height for the newly created thumbs (or width, if the image is in portrait format) */
$MAXIMGWIDTH=800; /* The maximum width (or height, if portrait) to resize the images if they are too big */
$MAXIMGHEIGHT=600; /* The maximum height (or width, if portrait) to resize the images if they are too big */
									/* IMPORTANT: The program will not enlarge the images, so for example a 640x480 photo
										will remain unchanged; thus, if you don't want your images resized, just set this numbers
										to an arbitrarily large value, like 9999 */
$ROWSPAGE=9; /* Rows of pictures in each page (4 pictures per row, so 9 rows means 36 pictures) */
$CAPTION_ON_TOP=1; /* Should the picture captions appear on top of the pop-up window? Put 1 for yes, 0 for no. */
$MAX_UPL_SIZE=50331648; /* Maximum size for uploaded pics or zipfiles, in bytes. WARNING: THIS IS NOT A HARD LIMIT, IT IS ONLY ADVISORY TO THE BROWSER; THE "REAL" LIMIT IS IN php.ini */
$DELETE_IMAGE_FILES=1; /* If set to other than zero, image files will be physically deleted when an image is removed from the album via the admin module */
$MAX_ZIPENTRY_SIZE=2097152; /* Maximum size for the individual files that can be found inside a zip file */

/***************************** END OF CONFIGURATION AREA; COMMON CODE FOLLOWS ************************/

/* In PHP 4.1 a new feature, the "superglobal variables", was introduced. What's more, starting with 4.2 the */
/* parameter named REGISTER_GLOBALS is set to OFF by default. This makes the form parameters fail */
/* "inexplicably" for some users. Since the old method of getting the parameters will eventually be deprecated, */
/* I'm using the new one but still supporting the good (?) old ways for versions previous to 4.1 */
	if (phpversion() < '4.1') {
		if ($_HTTP_SERVER_VARS["REQUEST_METHOD"] == "GET") {
			$idm = $HTTP_GET_VARS["idm"];
			$alb = $HTTP_GET_VARS["alb"];
			$page = $HTTP_GET_VARS["page"];
			$picture = $HTTP_GET_VARS["picture"];
		}
		if ($_SERVER["REQUEST_METHOD"] == "POST") {
			$idm = $HTTP_POST_VARS["idm"];
			$alb = $HTTP_POST_VARS["alb"];
			$page = $HTTP_POST_VARS["page"];
			$picture = $HTTP_POST_VARS["picture"];
		}
	}
	else {
		if ($_SERVER["REQUEST_METHOD"] == "GET") {
			$idm = $_GET["idm"];
			$alb = $_GET["alb"];
			$page = $_GET["page"];
			$picture = $_GET["picture"];
		}
		if ($_SERVER["REQUEST_METHOD"] == "POST") {
			$idm = $_POST["idm"];
			$alb = $_POST["alb"];
			$page = $_POST["page"];
			$picture = $_POST["picture"];
		}
	}

$VERNUM="3.2.2"; /* Version number, moved here from the different language files */
/* Language loading; if it's an admin page, $adminprefix will be "../", else it will be empty */
if (!file_exists($adminprefix.'lang_'.$idm.'.inc')) { /* If the language is empty or non-existent, let's set a default */
  $idm = $DEFAULT_IDM;
}
include ('lang_'.$idm.'.inc'); /* Now we load the language strings file */

/***************************************************************************************************
 ******************************  Some functions of common use **************************************
 ***************************************************************************************************/

/* This routine creates the hash array "langlist" containing the available languages, in the format
 * "langcode --> langname" (example: "en-->English); it works by scanning the directory for "lang_xx"
 * files and building an array with them. */

function createLanglist ($askdir) {
	if ($dir = @opendir($askdir)) {
		while (($file = readdir($dir)) !== false) {
			if(substr($file,0,5) == "lang_") {
				$langcode = substr($file, 5, 2);
				$fp = fopen ($askdir.'/'.$file,'r');
				while ($data = fgets($fp,1000) ) {
					if (strpos($data, "LANG_LANGUAGE")) { /* We read the language name */
						$langname = substr($data, strpos($data, "\"")+1, strrpos($data, "\"")-strpos($data, "\"")-1);
					}	
					if (strpos($data, "LANG_CHARSET"))	{ /* Here we read the charset for this language; I am not sure if it will be useful or not */
						$langcset = substr($data, strpos($data, "\"")+1, strrpos($data, "\"")-strpos($data, "\"")-1);
					}
				}
				fclose ($fp);
				$langlist[$langcode] = $langname;
				$langlset[$langcode] = $langcset; /* I'd like to use this for each language, but I don't know how; anyway, UTF-8 should do for everyone */
			}
		}
		closedir($dir);
	}
	return array($langlist, $langlset);
}
?>
